==> paraview-v1.0.3.zip: paraview-v1.0.3/ParaView/Widgets/vtkKWOKCancelDialog.h <==
/*=========================================================================

Copyright (c) 1998-2003 Kitware Inc. 469 Clifton Corporate Parkway,
Clifton Park, NY, 12065, USA.
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

 * Redistributions of source code must retain the above copyright notice,
   this list of conditions and the following disclaimer.

 * Redistributions in binary form must reproduce the above copyright notice,
   this list of conditions and the following disclaimer in the documentation
   and/or other materials provided with the distribution.

 * Neither the name of Kitware nor the names of any contributors may be used
   to endorse or promote products derived from this software without specific
   prior written permission.

 * Modified source versions must be plainly marked as such, and must not be
   misrepresented as being the original software.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/
// .NAME vtkKWOKCancelDialog - a dialog box with an OK and Cancel button
// .SECTION Description
// A class for OKCancelDialog boxes.

#ifndef __vtkKWOKCancelDialog_h
#define __vtkKWOKCancelDialog_h

#include "vtkKWDialog.h"
class vtkKWApplication;

class VTK_EXPORT vtkKWOKCancelDialog : public vtkKWDialog
{
public:
  static vtkKWOKCancelDialog* New();
  vtkTypeRevisionMacro(vtkKWOKCancelDialog,vtkKWDialog);
  void PrintSelf(ostream& os, vtkIndent indent);

  // Description:
  // Create a Tk widget
  virtual void Create(vtkKWApplication *app, const char *args);

  // Description:
  // Set the text of the message
  void SetText(const char *);
  
protected:
  vtkKWOKCancelDialog();
  ~vtkKWOKCancelDialog();

  vtkKWWidget *Message;
  vtkKWWidget *ButtonFrame;
  vtkKWWidget *OKButton;
  vtkKWWidget *CancelButton;
private:
  vtkKWOKCancelDialog(const vtkKWOKCancelDialog&); // Not implemented
  void operator=(const vtkKWOKCancelDialog&); // Not implemented
};


#endif

==> paraview-v1.2.0.zip: paraview-v1.2.0/ParaView/Widgets/vtkKWOKCancelDialog.h <==
/*=========================================================================

  Module:    vtkKWOKCancelDialog.h

  Copyright (c) Kitware, Inc.
  All rights reserved.
  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.

     This software is distributed WITHOUT ANY WARRANTY; without even
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
     PURPOSE.  See the above copyright notice for more information.

=========================================================================*/
// .NAME vtkKWOKCancelDialog - a dialog box with an OK and Cancel button
// .SECTION Description
// A class for OKCancelDialog boxes.

#ifndef __vtkKWOKCancelDialog_h
#define __vtkKWOKCancelDialog_h

#include "vtkKWDialog.h"
class vtkKWApplication;

class VTK_EXPORT vtkKWOKCancelDialog : public vtkKWDialog
{
public:
  static vtkKWOKCancelDialog* New();
  vtkTypeRevisionMacro(vtkKWOKCancelDialog,vtkKWDialog);
  void PrintSelf(ostream& os, vtkIndent indent);

  // Description:
  // Create a Tk widget
  virtual void Create(vtkKWApplication *app, const char *args);

  // Description:
  // Set the text of the message
  void SetText(const char *);
  
protected:
  vtkKWOKCancelDialog();
  ~vtkKWOKCancelDialog();

  vtkKWWidget *Message;
  vtkKWWidget *ButtonFrame;
  vtkKWWidget *OKButton;
  vtkKWWidget *CancelButton;
private:
  vtkKWOKCancelDialog(const vtkKWOKCancelDialog&); // Not implemented
  void operator=(const vtkKWOKCancelDialog&); // Not implemented
};


#endif
